Handbook - Reproductive System Somatic Gonad
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

REPRODUCTIVE SYSTEM THE SOMATIC GONAD Click pictures for new window with figure and legend, click again for high resolution image
1 General Description The somatic gonad refers to the non-germ-line component of each arm (SomaticFIG 1). It consists of five tissues, each with specific functions and distinct anatomical features: the DTCs, gonadal sheath, spermatheca, spermatheca-uterine valve, and the uterus (covered in Reproductive System - Egg-laying Apparatus ). These tissues, in particular the sheath and DTC, are intimately associated with the germ line and have a critical role in its development, organization, and function in the adult (Kimble and White, 1981; McCarter et al., 1997; Hall et al., 1999). All cells of the somatic gonad derive from two founder cells Z1 and Z4 that are present in the L1 gonad primordium (SomaticFIG 1). By L2, Z1/Z4 have generated 12 descendants: two DTCs, required for gonad elongation and germ-line patterning; nine blast cells that will, collectively, generate all other adult somatic gonad cells; and one anchor cell (AC), a transient cell that functions to pattern the cells of the vulva. Somatic and germ cells are intermingled until the L2/L3 molt, at which time they rearrange to establish the general organization of the future gonad (SomaticFIG 1). The DTCs are positioned at the anterior and posterior of the developing gonad. The ten remaining cells gather at the center to form the somatic gonadal primordium of the hermaphrodite (SPh), thus dividing the germ line into anterior and posterior populations of cells or arms (Kimble and Hirsh, 1979). SomaticFIG 1: Development of the somatic gonad, lateral view. Top Schematic of the L1 gonadal primordium showing Z1 and Z4, which give rise to tissues of the somatic gonad, and Z2 and Z3, which generate the germ line. Middle Schematic of cells of the somatic gonadal primordium of the hermaphrodite (SPh) showing the arrangement of Z1 and Z4 descendants, the somatic gonad precursors, and the DTCs. Cells arrange in one of two configurations (5L or 5R), depending on whether Z1ppp or Z4aaa becomes the anchor cell (AC). The developing germ line occupies the area between the DTCs and the somatic gonad precursors. Precursors in the SPh are colored according to the adult tissues to which they will contribute. Precursors: (DU) dorsal uterine; (SS) spermatheca/sheath; (VU) ventral uterine. Bottom Differential interference contrast (DIC) microscopy image of an adult anterior gonad arm. The extent and location of mature somatic gonad tissues are indicated by the color overlay. Magnification, 400x. (Based on Kimble and Hirsh, 1979; McCarter et al., 1997.)
2 The Distal Tip Cell The DTC is a single, large somatic cell located at the tip of each gonad arm. It forms a close-fitting cap over the distalmost 6–10 germ cells. No intervening basement membrane or specialized intercellular junctions are found between the DTC and germ cells. Several thin cytoplasmic arms (tentacle-like cytonemes), less tightly associated with germ cells, extend from the cap for an average of 8 ± 4 cell diameters (but can extend as far as 20 cell diameters; SomaticFIG 2A,B). The gonadal basal lamina (GBL), which covers the entire outer surface of the gonad, is thickened in the region of the DTC (SomaticFIG 2C). Fragments of the GBL appear to be shed from the trailing arms of the DTC into the pseudocoelom. The DTC has a large nucleus located at its leading (distal) edge and its cytoplasm is filled with distinctive membrane-bounded vacuoles, some rough endoplasmic reticulum (RER), and mitochondria. The plasma membrane sometimes displays “omega” figures (see SomaticFIG 2E) where it faces the GBL, indicative of active endocytosis or exocytosis. The gross anatomy of the DTC cell, born in the L1, does not alter significantly during the course of development, although the adult cell appears to contain more and longer cytonemes extending over the germ line (D.H. Hall and E.M. Hedgecock, unpubl.). The hermaphrodite DTC has two major functions: (1) gonadal arm elongation during development and (2) promoting mitosis and/or inhibiting meiosis of the germ cells, both during development and in the adult. SomaticFIG 2A: Scanning electron micrograph of the DTC. A. Lateral view. Distal-most end of an adult gonad (dissected away from the rest of the body). (Image source: L. Hoffman and D. Greenstein.) SomaticFIG 2B&C: Transmission electron micrograph images of the DTC. B. Longitudinal section, from the region indicated by the box in A (late L4 DTC). (Hyp) Hypodermis; (N) nucleus. (Image source: Hall archive.) C. Longitudinal section, from the region indicated by the box in B. Colored lines indicate the boundaries of the DTC and the germ line. (GBL) Gonadal basal lamina. (Image source: Hall archive.) SomaticFIG 2D&E: Transmission electron micrograph images of the DTC. D. Longitudinal section, shows fragments of the GBL shed from the trailing arms of the DTC into the pseudocoelom. (Hyp) Hypodermis; (GBL) Gonadal basal lamina. (Image source: Hall archive.) E. Longitudinal section, from an area of the plasma membrane that sometimes displays "omega"figures where it faces the GBL, indicative of active endocytosis or exocytosis. (N) nucleus. (Image source: Hall archive.)
2.1 Gonadal Arm Elongation The gonad arms acquire their U shape by the directed migration of the DTC, which acts as a leader cell (SomaticFIG 3A–D). Arm elongation begins in L2 (21 hr, 20°C) and continues, proceeding at variable rates, until the L4 molt (45 hr) (Antebi et al., 1997; D.H. Hall and E.M. Hedgecock, unpubl.). During migration, the DTC glides along the basal laminae of body wall muscles and hypodermis. The DTC produces a metalloprotease (GON-1) that is hypothesized to facilitate migration by remodeling the basal laminae during gonad extension (Blelloch and Kimble, 1999; Blelloch et al., 1999). In contrast to neuronal growth cones, the leading edge of the DTC is broad and blunt during migration and bears no fingers or lamellipodia (SomaticFIG 2). Genetic functions that control elongation include global guidance molecules (such as unc-6, unc-5, and unc-40) (Hedgecock et al., 1987; 1990) and cell recognition functions such as those defined by the programmed cell death corpse engulfment genes (e.g., ced-2, ced-5, and ced-10) (Conradt, 2001). DTC migration also appears to be sensitive to global signals of the developmental stage because migration halts during dauer arrest and is advanced or delayed in heterochronic mutant backgrounds (Ambros, 1997; Antebi et al., 1997). SomaticFIG 3A-D: The DTC regulates gonad elongations during development. DIC/epifluorescent images of lag-2::GFP transgenic hermaphrodites at various stages of gonad development, anterior gonad arm, lateral view, left side. lag-2 is expressed in the DTC. The posterior gonad arm (not shown) elongates in the opposite direction from the midbody (arrowhead), producing a mirror image of the anterior gonad arm. A. Late L1; B. late L2/early L3; C. mid-L3; D. L4. Magnification, 1000x. (Strain source: D. Gao and J. Kimble.) SomaticFIG 3E: The stages of gonad arm elongation. Illustration shows process of gonad elongation with time. Time is post-hatching at 20°C. Note: basal laminae associated with gonad, muscle and hypodermis not shown. (Adapted from Hedgecock et al, 1987; Antebi et al., 1997.)
2.2 Regulation of Germ-line Mitosis Versus Meiosis Entry The adult germ line exhibits distal–proximal polarity with mitotic cells at the distalmost end and meiotic cells filling the remainder of the gonad (SomaticFIG 4). Ablation of the DTC causes all mitotic nuclei to become meiotic and all meiotic nuclei to mature into gametes, the fate of the proximalmost meiotic germ cells (Kimble and White, 1981; Austin and Kimble, 1987; Lambie and Kimble, 1991). The DTC regulates entry into mitosis versus meiosis through a Notch/LIN-12 signal transduction pathway (Lambie and Kimble, 1991; Crittenden et al., 1994; Henderson et al., 1994; Tax et al., 1994). The DTC expresses the pathway ligand LAG-2 (Lin and Glp), whereas the germ line expresses the pathway receptor GLP-1 (germ-line proliferation abnormal mutant phenotype) and downstream effectors (SomaticFIG 2 and SomaticFIG 4B). Pathway activation blocks entry into meiosis (or promotes mitosis), maintaining germ cells near the DTC in a mitotic state (Hansen et al., 2004). It is hypothesized that germ cells enter meiosis by default due to their increased distance from the DTC. During development, the exact position and timing of the initial onset of meiosis at L3 is influenced by both DTC and non-DTC somatic cells (see GermFIG 6) (Pepper et al., 2003; Killian and Hubbard, 2004). Much of the DTC–germ-line contact region falls short of the mitotic zone proximal boundary (SomaticFIG 4), suggesting that pathway activation must be propagated in some way to explain how cells that are not in direct contact with DTC stay in a mitotic state (see PeriFIG 3) (for models, see Crittenden et al., 1994; 2003). SomaticFIG 4: Distal–proximal polarity of germ-line cell nuclei morphologies as they progress from mitosis through the various stages of meiotic prophase I. A-D. Epifluorescent images of DAPI-stained adult hermaphrodite (dissected) gonads. (Image source: J. Maciejowski and E.J. Hubbard.) A. Germ line of one gonad arm (a montage of three individual gonad arms; dashed lines correspond to regions not covered by individual gonad images). Indicated are stages of meiotic prophase I (orange text) and the relative positions of somatic tissues (color lines). (PCD) Programmed cell death. Magnification, 400x. B-D. Mitosis and meiotic prophase I. B. Distalmost region of the gonad from a lag-2::GFP adult transgenic animal. The lag-2::GFP reporter (green) is expressed in the DTC. DAPI-stained germ-line nuclei (blue) close to the DTC are mitotic, whereas those more proximal are entering into meiosis and define the transition zone. This zone characteristically contains crescent-shaped nuclei (arrowheads). C&D. DAPI staining only. Magnification, 1000x. 3 Gonadal Sheath Cells Five pairs of thin gonadal sheath cells form a single layer covering the germ-line component of each arm. Each pair occupies a stereotyped position along the gonad proximal–distal axis. The neighboring sheath-cell borders partially overlap, and occasional gap junctions and macular adherens junctions are observed between cells in these regions (see also Gap Junctions). Sheath cells are intimately associated with the germ line and are necessary for several aspects of germ-line development. Sheath cells or their precursors promote germ-line proliferation and exit from pachytene, gametogenesis, and male gamete fate during germ-line sex determination (Seydoux et al., 1990; McCarter et al., 1997; Rose et al., 1997; Killian and Hubbard, 2004). In the adult, distal sheath cells engulf germ cells eliminated by programmed cell death (see Reproductive system - Germ Line). Proximal sheath cells are necessary for oocyte maturation and ovulation and function permissively in the process of yolk protein uptake by oocytes (Grant and Hirsh, 1999; Hall et al., 1999; McCarter et al., 1999). Sheath cells arise from the SS blast cells present in the L2/L3 SPh (SomaticFIG 1, SomaticFIG 5A). During gonadogenesis, sheath cells reach their final distal–proximal location either by being pulled along with or crawling along the growing germ line (Kimble and Hirsh, 1979; McCarter et al., 1997). Distal and proximal sheath cells of the adult express quite different characteristics. Sheath-cell pair 1 (SomaticFIG 5B-E), which overlies the distal germ line, in particular, is strikingly different from the more proximal pairs 3–5, which overlie developing oocytes. Pair 2, located over the loop, appears to express properties intermediate to the distal and proximal pairs. SomaticFIG 5A-C: Distal and proximal gonadal sheath cells. A. Illustration showing the lineage of the sheath cells as they develop from one of four SS (spermatheca/sheath) precursor cells. (Adapted from McCarter et al., 1997.) B. DIC image of an adult showing one gonad arm. The 5 pairs of sheath cells are colored in purple with the cell borders highlighted. C. Immunostaining of one dissected adult gonad arm. Marker is anti-CEH-18 which stains sheath cell and DTC (not visible) nuclei. White arrows indicate nuclei. (Image source: D. Killian and E.J. Hubbard.) SomaticFIG 5D&E: Distal and proximal gonadal sheath cells have different characteristics. D. Epifluorescent image showing the anterior gonad arm of a lim-7::GFP transgenic adult hermaphrodite, lateral view, left side. Five pairs of sheath cells (numbered 1–5) cover the arm. The LIM-7::GFP signal is strong in sheath-cell pairs 1–3, weak in 4, and absent from 5. The approximate position of sheath-cell borders is indicated by the dotted line. (N) Nucleus; (PG) proximal gonad; (DG) distal gonad. Magnification, 400x. (Strain source: O. Hobert.) E. Epifluorescent image of an adult (dissected) gonad arm costained with DAPI (blue, cell nuclei) and rhodamine phalloidin (red, actin). Magnification, 400x. (Image source: D. Killian and E.J. Hubbard.) 3.1 Distal Sheath-cell Pair 1 The cytoplasm of these cells forms concentrated wedges between germ cells and a thin layer over them, giving pair 1 a net-like appearance (SomaticFIG 5D and SomaticFIG 6A). Distally, cells extend filopodia that form an irregular meshwork running between germ cells (Hall et al., 1999). Beneath this distal sheath pair, germ cells are gradually flowing proximally toward the loop, propelled by both the generation of new germ cells distally and the loss of some germ cells to apoptosis and/or ovulation more proximally. Thus, the distal sheath cells may be in a perpetually crawling phase, just to keep their place over the moving germ line. SomaticFIG 6: Electron micrographs of the adult gonadal sheath. A. TEM, transverse section of the distal gonad arm. B-D. TEM, longitudinal sections of the proximal gonad arm. Purple lines show edges of sheath cells. In D, white asterisks indicate yolk protein and black arrowheads show gap junctions. (Image source: Hall archive.) 3.2 Proximal Gonad Sheath-cell Pairs Pairs 3–5 differ dramatically from sheath-cell pair 1 in their morphology and ultrastructural characteristics (SomaticFIG 5A and SomaticFIG 5D&E). Pairs 3–5 express muscle components such as the filament proteins actin (detected with rhodamine phalloidin) and myosin, and the thin filament-associated muscle protein UNC-87 (Hirsh et al., 1976; Strome, 1986; Goetinck and Waterston, 1994; McCarter et al., 1997). These filaments are organized into dense networks. In pairs 3 and 4, filaments are predominantly longitudinally oriented, whereas in pair 5, filaments are both longitudinally and circumferentially oriented (SomaticFIG 5E). Filaments are also present in the distal sheath cells but are much less abundant. The presence of dense networks in proximal cells is consistent with their contractile properties. Proximal sheath contraction is required for ovulation and transfer of the oocyte into the spermatheca for fertilization. During ovulation, proximal sheath-cell contraction pulls the dilated spermatheca over the proximalmost oocyte. Neither the sheath nor the spermatheca (see below) appears to be innervated. Therefore, these tissues may be similar to arterial smooth muscle and potentially regulate contraction and relaxation through calcium sparks (see Bui and Sternberg, 2002, and references therein). Gap junctions are seen occasionally between sheath cells and between the apical sheath-cell surface and oocytes (SomaticFIG 6C&D) (Hall et al., 1999) (see also Gap Junctions). Contraction of sheath cells is coupled to oocyte maturation and the presence of sperm (see Reproductive System - Germ Line; McCarter et al., 1999; Miller et al., 2001, 2003). Sheath:sheath and sheath:oocyte gap junctions may therefore facilitate the coordination of the oocyte stage and sheath contraction rate with the presence of sperm. Sheath-cell pairs 4 and 5 also contain numerous pores (SomaticFIG 6B). Yolk particles produced in the intestine pass through the gonadal basal lamina and the sheath pores, gaining entry to the oocytes by the process of endocytosis (Grant and Hirsh, 1999; Hall et al., 1999). 4 The Spermatheca The spermatheca, the site of oocyte fertilization, is an accordion-like tube that contains sperm. It is composed of 24 cells organized into two regional groups: distally, 8 cells aligned in two rows that form a narrow corridor or neck, and proximally, 16 cells that form a wider bag-like chamber (Kimble and Hirsh, 1979; McCarter et al., 1997). In the absence of an oocyte, the adult spermatheca lumen is narrow and the apical surfaces of cells lining it are highly convoluted, providing the potential for expansion and an adherent surface for sperm (SomaticFIG 7A; compare SomaticFIG 8A&B). The outer (basal) surface displays numerous longitudinal folds of collapsed membranes (SomaticFIG 7A) that may also allow for the radial expansion of the spermatheca during oocyte passage. SomaticFIG 7: Electron micrographs of adult gonad. A. SEM, dorsolateral view of an adult (dissected) gonad, proximal arm. The spermatheca (Sp) is empty of oocytes. Scale bar, 6.1 �m. (Image source: L. Hoffman and D. Greenstein.) B. TEM, transverse section from the proximal arm of the adult gonad, in the region of the sp-ut valve. (Image source: N2U [MRC] 4989-13.) SomaticFIG 8A&B: Changes in spermathecal lumen shape and size observed between and during fertilizations. Epifluorescent images of adult spermatheca from dissected gonads. A. Empty adult spermatheca co-immunostained with anti-RNF-5 antibodies (red, Ring Finger Protein 5, which localizes to septate junctions on the apical/lumenal surface) and anti-AJM-1/MH27 antibodies (green, Apical Junction Molecule 1, which localizes to adherens, and pleated and smooth/continuous septate junctions of the apical/lumenal and lateral borders) (Broday et al., 2004). (Sp) Spermatheca. B. Inflated adult spermatheca immunostained with anti-AJM-1/MH27 antibodies (red). Magnification, 1000x. (Image source: L. Broday and I. Koloteuv.) Spermathecal cells are rich in actin microfilaments that are organized into circumferentially oriented networks (SomaticFIG 8C). Myosin, however, has not yet been detected (Strome, 1986; McCarter et al., 1997). Circumferential dilation of the distal spermatheca during ovulation is triggered in response to activation of the LIN-3/LET-23 receptor tyrosine kinase (RTK) pathway by the maturing primary oocyte (see Reproductive System - Germ Line). Pathway activation causes an increase in IP3 levels, which leads to dilation, possibly by a mechanism involving calcium release (Clandinin et al., 1998; McCarter et al., 1999; Bui and Sternberg, 2002). Tight regulation of inositol-1,4,5-triphosphate (IP3) levels appears to be necessary to ensure that dilation is strictly controlled so that only one oocyte at a time is enveloped by the spermatheca (Bui and Sternberg, 2002). Gap junctions are located on the lateral borders between sheath and spermathecal cells (see Gap Junctions). These could serve to synchronize spermatheca dilation and relaxation with contraction of the sheath. SomaticFIG 8C: Spermathecal cells are rich in actin microfilaments. Epifluorescent image of adult spermatheca from dissected gonads showing acting filaments with red actin marker (rhodamine-phalloidin). (Sp) Spermatheca. Distal gonad is toward the left and proximal gonad is toward the right. (Image source: D. Killian and E.J. Hubbard.) Spermathecal cells arise from SS and DU blast cells of the somatic primordium; 18 cells are the products of the SS cells and 6 derive from the DUs (SomaticFIG 1; SomaticFIG 5A) (Kimble and Hirsh, 1979; Newman et al., 1996; McCarter et al., 1997). The terminal cells form a spermatheca with a lumen by late L4; however, this organ does not achieve its adult form until the first oocyte has passed through it (J. White, unpubl.). Before the first ovulation, the newly formed spermatheca is devoid of sperm (SomaticFIG 9A and see GermFIG 6). Male gametes are generated in the gonadal sheath lumen and remain there until passage of the first mature oocyte pushes them into the spermatheca. This first ovulation event also results in loss or reduction of numerous filopodia that extend from apical membranes into the spermathecal lumen (SomaticFIG 9C) (D.H. Hall, unpubl.; J. White, unpubl.). Maturing spermathecal cells (SomaticFIG 9B) have a dark cytoplasm (granular by differential interference contrast [DIC] microscopy) and are covered by a thick basal lamina on their basal surface. Cells are organized into a spiral structure with a single left-handed twist along the organ’s anterior–posterior axis. This arrangement likely contributes to the complex twisting of cell borders, which are hard to resolve, even at high magnification. Each cell contributes a portion of its apical side to the lumenal surface and its basal side to the outer surface of the tissue. Cell surfaces bear a variety of junction types, several of which are recognized by the anti-AJM-1 antibody MH27: the adherens, pleated septate, and smooth/continuous septate junctions (SomaticFIG 8A,B; SomaticFIG 9C; Somatic FIG 9EF) (D.H. Hall, unpubl.). Apical surfaces bear adherens and pleated septate junctions, whereas lateral surfaces bear smooth/continuous septate and gap junctions (SomaticFIG 9B–D; Somatic FIG 9EF). The pleated septate and continuous junctions, on either side of the adherens junctions, may zip and unzip as oocytes pass through the organ (SomaticFIG 9D) (J. White, pers. comm.). SomaticFIG 9A: Formation of the spermatheca. DIC image of a late L4 hermaphrodite spermatheca (before the first ovulation) showing that at this point, the newly formed spermatheca is devoid of sperm. For detailed imaging of white boxed region, see SomaticFIG 9B. (DG) distal gonad; (PG) proximal gonad; (sp) spermatheca. (Image source: Hall archive.) SomaticFIG 9B-D: Cell junctions of the spermatheca. B. TEM, transverse section of a late L4 hermaphrodite spermatheca (before the first ovulation). The number of cells that make up the spermathecal wall is indicated. The lumenal (apical) surface (heavy blue lines) bears filopodia, pleated septate junctions, and adherens junctions. The lateral cell borders (thin blue lines) contain smooth/continuous septate junctions and gap junctions (see C). (N) Nucleus; (nl) nucleolus. (Image source: VS8/1 [MRC] 4935-3.) C. TEM, transverse section showing a high-magnification view of junction types from the areas indicated by the box in B. (Image source: Hall archive.) D. Schematic of the spermatheca (transverse view) showing the possible roles for junction types in spermatheca function (see text). (aj) Adherens junction; (psj) pleated septate junction; (s/csj) smooth/continuous septate junction. SomaticFIG 9EF: Cell junctions of the spermatheca. E&F. TEMs showing junction types that are recognized by MH27 (AJM-1) as shown by immuno EM (Image source: Hall archive.) (aj) Adherens junction; (psj) pleated septate junction; (s/csj) smooth/continuous septate junction (gj) gap junction. 5 The Spermathecal-uterine Valve After oocyte fertilization, the newly formed embryo passes from the spermatheca to the uterus via a connecting valve, the sp-ut valve (SomaticFIG 10A). The adult valve consists of a toroidal syncytium generated by the fusion of four cells (sujns) (SomaticFIG 10C) (Kimble and Hirsh, 1979). SomaticFIG 10: The spermathecal-uterine valve. A. DIC view of an adult hermaphrodite spermatheca (Sp) and sp-ut valve. Distal (DG) and proximal (PG) gonad. Magnification, 1000x. B. DIC/epifluorescent image of a late-L4 cog-1::gfp transgenic animal before first ovulation. (Strain source: R.E. Palmer and P.W. Sternberg.) C. TEM, transverse section of a late-L4 hermaphrodite spermathecal-uterine valve. Four sujn cells form a toroidal syncytium that constitutes the adult valve. The center of the valve is occupied by a syncytial core formed by two sujc cells. The core is displaced by the first ovulation event. (Image source: VS8/1 [MRC] 4920-14. Like the spermatheca, the morphology of the sp-ut valve is altered by passage of the first fertilized oocyte. Before the first ovulation, the center of the toroid is occupied by two junctional core cells, also syncytial (sujcs) (Kimble and Hirsh, 1979). The core cells extend pseudopodia into the apical folds of the sujn cells, and core cell nuclei protrude into the uterus lumen (SomaticFIG 10B&C) (Kimble and Hirsh, 1979). Passage of the first fertilized oocyte apparently pushes the core cell bodies away to open the passage. The fate of the displaced core cells is not known. The anatomy of the sujn valve cells has been followed in serial sections (E. Southgate and J. White, pers. comm.). The outward (basal surface) of the valve is encircled by a thick basal lamina. At its apical (lumenal) face, valve membranes appear to zip together by pleated septate junctions, in the same manner as the spermatheca, thus sealing the lumen when empty (SomaticFIG 10C). Valve cells extend many interlocking fingers into the valve-spermatheca interface. These, together with possible adherens and septate junctions, may serve to hold the adjacent tissues together. On the opposite side, where the valve faces the nearest uterine epithelial cells (ut4), the lateral cell borders contain extensive septate junctions and possibly some adherens junctions. 6 List of Somatic Gonad Cells (See Z1Z4 lineages) 1. Late L2/early L3 stage SPh Z1.aa (Distal Tip Cell, anterior) SS, Z1.ap (Somatic sheath and Spermatheca precursor) SS, Z1.paa (Somatic sheath and Spermatheca precursor) DU, Z1.pap (Dorsal Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VUs and AC are of either the 5R or 5L configuration: 5R configuration VU, Z1.ppa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) AC, Z1.ppp (Anchor Cell) VU, Z4.aaa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VU, Z4.aap (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) 5L configuration VU, Z1.ppa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VU, Z1.ppp (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) AC, Z4.aaa (Anchor Cell) VU, Z4.aap (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) DU, Z4.apa (Dorsal Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) SS, Z4.app (Somatic sheath and Spermatheca precursor) SS, Z4.pa (Somatic sheath and Spermatheca precursor) Z4.pp (Distal Tip Cell, posterior) 2. Adult anterior gonad arm i. Distal Tip Cell of anterior gonad arm: Z1.aa ii. Somatic Sheath (10 cells/5 pairs) of anterior gonad arm: Z1.apa (sheath cell 1) Z1.appaaa (sheath cell 2) Z1.appaap (sheath cell 3) Z1.appapa (sheath cell 4) Z1.appapp (sheath cell 5) Z1.paaa (sheath cell 1) Z1.paapaaa (sheath cell 2) Z1.paapaap (sheath cell 3) Z1.paapapa (sheath cell 4) Z1.paapapp (sheath cell 5) iii. Spermatheca (24 cells) of anterior gonad arm: Z1.apppaaaa Z1.apppaaap Z1.apppaapa Z1.apppaapp Z1.apppapaa Z1.apppapap Z1.apppapp Z1.appppa Z1.appppp Z1.paappaaaa Z1.paappaaap Z1.paappaapa Z1.paappaapp Z1.paappapaa Z1.paappapap Z1.paappapp Z1.paapppa Z1.paapppp Z1.papaaad Z1.papaaav Z1.papaapv Z4.apaaaad Z4.apaaaav Z4.apaaapv iv. Spermatheca-uterine valve and core (both syncytial) of anterior gonad arm: Z1.papaapd; Z4.apaaapd (2 sujc cells that fuse to make the "core" syncytium, lost after the 1st ovulation) Z1.papapaaa; Z1.ppaaaaa; Z1.ppaaapa; Z4.apaapaaa (4 sujn cells that fuse to make the valve syncytium) 3. Adult posterior gonad arm i. Distal Tip Cell of posterior gonad arm: Z4.pp ii. Somatic Sheath (10 cells/5 pairs) of posterior gonad arm: Z4.pap (sheath cell 1) Z4.paappp (sheath cell 2) Z4.paappa (sheath cell 3) Z4.paapap (sheath cell 4) Z4.paapaa (sheath cell 5) Z4.appp (sheath cell 1) Z4.appappp (sheath cell 2) Z4.appappa (sheath cell 3) Z4.appapap (sheath cell 4) Z4.appapaa (sheath cell 5) iii. Spermatheca (24 cells) of posterior gonad arm: Z1.papppav Z1.pappppd Z1.pappppv Z4.apappav Z4.apapppd Z4.apapppv Z4.appaaaa Z4.appaaap Z4.appaapaa Z4.appaapapa Z4.appaapapp Z4.appaappaa Z4.appaappap Z4.appaapppa Z4.appaapppp Z4.paaaaa Z4.paaaap Z4.paaapaa Z4.paaapapa Z4.paaapapp Z4.paaappaa Z4.paaappap Z4.paaapppa Z4.paaapppp 7 References Ambros, V. 1997. Heterochronic Genes. In C. elegans II (ed. D. L. Riddle et al.), pp. 501-518. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Antebi, A., Norris, C. R Hedgecock, E. M. and Garriga, G. 1997. Cell and Growth Cone Migrations. In C. elegans II (ed. D. L. Riddle et al.), pp. 583-609. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Austin, J., and Kimble, J. 1987. glp-1 is required in the germ line for regulation of the decision between mitosis and meiosis in C. elegans. Cell 51: 589-599. Abstract Blelloch, R. and Kimble, J. 1999. Control of organ shape by a secreted metalloprotease in the nematode Caenorhabditis elegans. Nature 399: 586-590. Abstract Blelloch, R., Anna-Arriola, S.S., Gao, D., Li, Y., Hodgkin, J. and Kimble, J. 1999. The gon-1 gene is required for gonadal morphogenesis in Caenorhabditis elegans. Dev. Biol. 216: 382-393. Article Broday, L., Kolotuev, I., Didier, C., Bhoumik, A., Podbilewicz, B., and Ronai, Z. 2004. The LIM domain protein UNC-95 is required for the assembly of muscle attachment structures and is regulated by the RING finger protein RNF-5 in C. elegans. J. Cell Biol. 165: 857-867. Article Bui, Y.K. and Sternberg, P.W. 2002. Caenorhabditis elegans inositol 5-phosphatase homolog negatively regulates inositol 1,4,5-triphosphate signaling in ovulation. Mol. Biol. Cell 13: 1641-1651. Article Clandinin, T. R., DeModena, J.A., and Sternberg, P.W. 1998. Inositol trisphosphate mediates a RAS-independent response to LET-23 receptor tyrosine kinase activation in C. elegans. Cell 92: 523-533. Article Conradt, B. 2001. Cell engulfment, no sooner ced than done. Dev. Cell 1: 445-447. Article Crittenden, S.L., Troemel, E.R. Evans, T.C., and Kimble J. 1994. GLP-1 is localized to the mitotic region of the C. elegans germ line. Development 120: 2901-2911. Article Crittenden, S.L., Eckmann, C.R., Wang, L., Bernstein, D.S., Wickens, M. and Kimble J. 2003. Regulation of the mitosis/meiosis decision in the Caenorhabditis elegans germline. Philos. Trans. R. Soc. Lond. B Biol. Sci. 358: 1359-1362. Article Goetinck, S. and Waterston, R.H. 1994. The Caenorhabditis elegans muscle-affecting gene unc-87 encodes a novel thin filament-associated protein. J .Cell Biol. 127: 79-93. Article Grant, B. and Hirsh, D. 1999. Receptor-mediated endocytosis in the Caenorhabditis elegans oocyte. Mol. Biol. Cell 10: 4311-4326. Article Greenstein, D., Hird, S., Plasterk, R.H., Andachi, Y., Kohara, Y., Wang, B., Finney, M., and Ruvkun, G. 1994. Targeted mutations in the Caenorhabditis elegans POU homeo box gene ceh-18 cause defects in oocyte cell cycle arrest, gonad migration, and epidermal differentiation. Genes Dev. 8: 1935-1948. Article Hall, D. H., Winfrey, V. P., Blaeuer, G., Hoffman, L. H., Furuta, T., Rose, K. L., Hobert, O., Greenstein, D. 1999. Ultrastructural features of the adult hermaphrodite gonad of Caenorhabditis elegans: relations between the germ line and soma. Dev Biol. 212: 101-123. Article Hansen, D., Wilson-Berry, L., Dang, T., and Schedl, T. 2004. Control of the proliferation versus meiotic development decision in the C. elegans germline through regulation of GLD-1 protein accumulation. Development 131: 93-104. Article Hedgecock, E.M., Culotti, J.G., Hall, D.H. and Stern, B.D. 1987. Genetics of cell and axon migrations in Caenorhabditis elegans. Development 100: 365-382. Article Hedgecock, E.M., Culotti, J.G., and Hall, D.H. 1990. The unc-5, unc-6, and unc-40 genes guide circumferential migrations of pioneer axons and mesodermal cells on the epidermis in C. elegans. Neuron 4: 61-85. Abstract Henderson, S.T., Gao, D., Lambie, E.J. and Kimble, J. 1994. lag-2 may encode a signaling ligand for the GLP-1 and LIN-12 receptors of C. elegans. Development 120: 2913-2924. Article Hirsh, D., Oppenheim, D. and Klass, M. 1976. Development of the reproductive system of Caenorhabditis elegans. Dev. Biol. 49: 200-219. Abstract Killian, D.J. and Hubbard, E.J. 2004. C. elegans pro-1 activity is required for soma/germline interactions that influence proliferation and differentiation in the germ line. Development 131: 1267-1278. Article Kimble, J.E. and Hirsh, D. 1979. The postembryonic cell lineages of the hermaphrodite and male gonads in Caenorhabditis elegans. Dev. Biol. 70: 396-417. Article Kimble, J.E. and White, J.G. 1981. On the control of germ cell development in Caenorhabditis elegans. Dev. Biol. 81: 208-219. Abstract Lambie, E.J. and Kimble, J. 1991. Two homologous regulatory genes, lin-12 and glp-1, have overlapping functions. Development 112: 231-240. Article McCarter, J., Bartlett, B., Dang, T., and Schedl, T. 1997. Soma-germ cell interactions in Caenorhabditis elegans: multiple events of hermaphrodite germline development require the somatic sheath and spermathecal lineages. Dev. Biol. 181: 121-143. Article McCarter, J., Bartlett, B., Dang, T., and Schedl, T. 1999. On the control of oocyte meiotic maturation and ovulation in Caenorhabditis elegans. Dev. Biol. 205: 111-128. Article Miller, M.A., Nguyen, V.Q., Lee, M.H., Kosinski, M., Schedl, T., Caprioli, R.M. and Greenstein, D. 2001. A sperm cytoskeletal protein that signals oocyte meiotic maturation and ovulation. Science 291: 2144-2147. Abstract Miller, M.A., Ruest, P.J., Kosinski, M., Hanks, S.K. and Greenstein, D. 2003. An Eph receptor sperm-sensing control mechanism for oocyte meiotic maturation in Caenorhabditis elegans. Genes Dev. 17: 187-200. Article Newman, A.P., White J.G. and Sternberg, P.W. 1996. Morphogenesis of the C. elegans hermaphrodite uterus. Development 122: 3617-3626. Article Pepper, A.S., Lo, T.W., Killian, D.J., Hall, D.H. and Hubbard, E.J. 2003. The establishment of Caenorhabditis elegans germline pattern is controlled by overlapping proximal and distal somatic gonad signals. Dev. Biol. 259: 336-350. Article Rose, K.L., Winfrey, V.P., Hoffman, L.H., Hall, D.H., Furuta, T. and Greenstein D. 1997. The POU gene ceh-18 promotes gonadal sheath cell differentiation and function required for meiotic maturation and ovulation in Caenorhabditis elegans. Dev. Biol. 192: 59-77. Article Seydoux, G., Schedl, T., and Greenwald, I. 1990. Cell-cell interactions prevent a potential inductive interaction between soma and germline in C. elegans. Cell 61: 939-951. Abstract Strome, S. 1986. Fluorescence visualization of the distribution of microfilaments in gonads and early embryos of the nematode Caenorhabditis elegans. J. Cell Biol. 103: 2241-2152. Article Tax, F.E,. Yeargers, J.J. and Thomas J.H. 1994. Sequence of C. elegans lag-2 reveals a cell-signalling domain shared with Delta and Serrate of Drosophila. Nature 368: 150-154. Abstract
This chapter should be cited as: Lints, R. and Hall, D.H. 2009. Reproductive system, somatic gonad. In WormAtlas. doi:10.3908/wormatlas.1.22 Edited for the web by Laura A. Herndon. Last revision: February 5, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |